
Salem
=====

Salem is a small library to do geoscientific data
processing and plotting. It extends `xarray`_ to add geolocalised
subsetting, masking, and plotting operations to xarray's `DataArray`_ and
`DataSet`_ structures.

.. _xarray: http://xarray.pydata.org/en/stable/
.. _DataArray: http://xarray.pydata.org/en/stable/data-structures.html#dataarray
.. _DataSet: http://xarray.pydata.org/en/stable/data-structures.html#dataset


Documentation
-------------

.. toctree::
    :maxdepth: 1

    examples
    faq
    whats-new
    installing
    xarray_acc
    plotting
    wrf
    gis
    auto_examples/index
    api


Get in touch
------------

- To ask questions or discuss Salem, send me an `e-mail`_.
- Report bugs, share your ideas or view the source code `on GitHub`_.

.. _e-mail: http://fabienmaussion.info/
.. _on GitHub: https://github.com/fmaussion/salem


License
-------

Salem is available under the open source `3-clause BSD license`_.

.. _3-clause BSD license: https://en.wikipedia.org/wiki/BSD_licenses


Citation
--------

If you are using salem and would like to cite it in academic publication, we
would certainly appreciate it. We recommend to use the zenodo DOI for
this purpose:

    .. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1295582.svg
       :target: https://doi.org/10.5281/zenodo.1295582


About
-----

:License:
    3-clause BSD

:Status:
    .. image:: https://badge.fury.io/py/salem.svg
        :target: https://badge.fury.io/py/salem
    .. image:: https://travis-ci.com/fmaussion/salem.svg?branch=master
        :target: https://travis-ci.com/fmaussion/salem
    .. image:: https://coveralls.io/repos/fmaussion/salem/badge.svg?branch=master&service=github
        :target: https://coveralls.io/github/fmaussion/salem?branch=master

:Documentation:
    .. image:: https://readthedocs.org/projects/salem/badge/?version=stable
        :target: http://salem.readthedocs.io/en/stable/?badge=stable

:Citation:
    .. image:: https://zenodo.org/badge/42607422.svg
        :target: https://zenodo.org/badge/latestdoi/42607422

:Contact:
    `Fabien Maussion <http://fabienmaussion.info/>`_
